==> velobox_update_3.0.2.tar.gz: usr/local/vmkstationd3/htdocs/production/js/dashboard.js <==
/*
Copyright (C) 2021 Velometrik GmbH
<http://www.velometrik.de/>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


/* 
    Created on : 04.06.2021, 21:08:29
    Author     : Peter Bauer
*/
// SATTELDRUCK
const host_s = `http://${location.host}`;
const ws_s = `ws://${location.host}`;
const apps_s = "satteldruckanalyse";

//HOCKER
const hocker = document.getElementById('hip').value || null;
localStorage.setItem('smartcube',hocker)
const host_h = `http://${hocker}`;
const ws_h = `ws://${hocker}/messages`;
const apps_h = null;
let con_img = document.getElementById("con_sitzkochen");
let link_sitzknochen = document.getElementById("link_sitzknochen");
var wsH;
let side_smartcube = document.getElementById('sitzknochen-menu');

// HOCKER WEBSOCKET
if(hocker!=null){
  wsH = new WebSocket(`${ws_h}`, ["soap", "wamp"]);
  let inter = setInterval(function () {
    if (wsH.readyState !=1) {
      noHocker();
    }
    clearInterval(inter);
   }, 1000);
   localStorage.setItem('hocker',"on")
   con_img.classList.remove('uk-blend-luminosity')
} else {
  noHocker();
}

function noHocker() {
  link_sitzknochen.classList.add("no-hocker");
  con_img.classList.add('uk-blend-luminosity');
  link_sitzknochen.setAttribute("onclick", 'LinkTo("system.tcls#smartcube")');
  side_smartcube.setAttribute('href','/production/system.tcls');
  localStorage.setItem('hocker',"off");
}

==> velobox_update_3.0.3.tar.gz: usr/local/vmkstationd3/htdocs/production/js/dashboard.js <==
/*
Copyright (C) 2021 Velometrik GmbH
<http://www.velometrik.de/>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

//DEV{}
function dev(params) {
  document.getElementsByClassName("version")[0].innerHTML="3.0.3_2"
}

/* 
    Created on : 04.06.2021, 21:08:29
    Author     : Peter Bauer
*/
// SATTELDRUCK
const host_s = `http://${location.host}`;
const ws_s = `ws://${location.host}`;
const apps_s = "satteldruckanalyse";

//HOCKER
const hocker = document.getElementById('hip').value || null;
localStorage.setItem('smartcube',hocker)
const host_h = `http://${hocker}`;
const ws_h = `ws://${hocker}/messages`;
const apps_h = null;
let con_img = document.getElementById("con_sitzkochen");
let link_sitzknochen = document.getElementById("link_sitzknochen");
var wsH;
let side_smartcube = document.getElementById('sitzknochen-menu');

// HOCKER WEBSOCKET
if(hocker!=null){
  wsH = new WebSocket(`${ws_h}`, ["soap", "wamp"]);
  let inter = setInterval(function () {
    if (wsH.readyState !=1) {
      noHocker();
    }
    clearInterval(inter);
   }, 1000);
   localStorage.setItem('hocker',"on")
   con_img.classList.remove('uk-blend-luminosity')
} else {
  noHocker();
}

function noHocker() {
  link_sitzknochen.classList.add("no-hocker");
  con_img.classList.add('uk-blend-luminosity');
  link_sitzknochen.setAttribute("onclick", 'LinkTo("system.tcls#smartcube")');
  side_smartcube.setAttribute('href','/production/system.tcls');
  localStorage.setItem('hocker',"off");
}

localStorage.removeItem('product1');
localStorage.removeItem('product2');
localStorage.removeItem('session_note');
localStorage.removeItem('session');
localStorage.removeItem('client_info');
localStorage.removeItem('client_id');
localStorage.removeItem('client_mail');
localStorage.removeItem('client_name');
localStorage.removeItem('note_session');
